Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(649)

Unified Diff: components/nacl/common/nacl_host_messages.h

Issue 649603004: Non-SFI NaCl: Batch-open resource files (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Remove ipc/ and mojo/ changes following Mark's suggestion Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/nacl/common/nacl_host_messages.h
diff --git a/components/nacl/common/nacl_host_messages.h b/components/nacl/common/nacl_host_messages.h
index 3a37e8f24e064ca0e81cdbd2a4ee72e614c6e3cc..dd8d8fd12fe326e585a0a3601ad4b3ccb831acd5 100644
--- a/components/nacl/common/nacl_host_messages.h
+++ b/components/nacl/common/nacl_host_messages.h
@@ -25,12 +25,20 @@ IPC_STRUCT_TRAITS_BEGIN(nacl::NaClLaunchParams)
IPC_STRUCT_TRAITS_MEMBER(nexe_file)
IPC_STRUCT_TRAITS_MEMBER(nexe_token_lo)
IPC_STRUCT_TRAITS_MEMBER(nexe_token_hi)
+ IPC_STRUCT_TRAITS_MEMBER(resource_files_info)
IPC_STRUCT_TRAITS_MEMBER(render_view_id)
IPC_STRUCT_TRAITS_MEMBER(permission_bits)
IPC_STRUCT_TRAITS_MEMBER(uses_nonsfi_mode)
IPC_STRUCT_TRAITS_MEMBER(process_type)
IPC_STRUCT_TRAITS_END()
+IPC_STRUCT_TRAITS_BEGIN(nacl::NaClLaunchParams::ResourceFileInfo)
+ IPC_STRUCT_TRAITS_MEMBER(file)
+ IPC_STRUCT_TRAITS_MEMBER(file_token_lo)
+ IPC_STRUCT_TRAITS_MEMBER(file_token_hi)
+ IPC_STRUCT_TRAITS_MEMBER(file_key)
+IPC_STRUCT_TRAITS_END()
+
IPC_STRUCT_TRAITS_BEGIN(nacl::NaClLaunchResult)
IPC_STRUCT_TRAITS_MEMBER(imc_channel_handle)
IPC_STRUCT_TRAITS_MEMBER(ppapi_ipc_channel_handle)
@@ -52,6 +60,17 @@ IPC_STRUCT_TRAITS_BEGIN(nacl::PnaclCacheInfo)
IPC_STRUCT_TRAITS_MEMBER(extra_flags)
IPC_STRUCT_TRAITS_END()
+IPC_STRUCT_TRAITS_BEGIN(nacl::NaClOpenExecutableResult)
+ IPC_STRUCT_TRAITS_MEMBER(file_info)
+ IPC_STRUCT_TRAITS_MEMBER(resource_files_info)
+IPC_STRUCT_TRAITS_END()
+
+IPC_STRUCT_TRAITS_BEGIN(nacl::NaClOpenExecutableResult::FileInfo)
+ IPC_STRUCT_TRAITS_MEMBER(file)
+ IPC_STRUCT_TRAITS_MEMBER(file_token_lo)
+ IPC_STRUCT_TRAITS_MEMBER(file_token_hi)
+IPC_STRUCT_TRAITS_END()
+
// A renderer sends this to the browser process when it wants to start
// a new instance of the Native Client process. The browser will launch
// the process and return an IPC channel handle. This handle will only
@@ -102,13 +121,12 @@ IPC_MESSAGE_CONTROL1(NaClHostMsg_MissingArchError,
int /* render_view_id */)
// A renderer sends this to the browser process when it wants to
-// open a NaCl executable file from an installed application directory.
-IPC_SYNC_MESSAGE_CONTROL2_3(NaClHostMsg_OpenNaClExecutable,
+// open NaCl resource files from an installed application directory.
+IPC_SYNC_MESSAGE_CONTROL3_1(NaClHostMsg_OpenNaClResources,
int /* render_view_id */,
GURL /* URL of NaCl executable file */,
- IPC::PlatformFileForTransit /* output file */,
- uint64 /* file_token_lo */,
- uint64 /* file_token_hi */)
+ std::vector<GURL> /* URLs of NaCl resource files */,
Mark Seaborn 2015/02/02 23:21:50 Same comment here: Can you merge this with the pre
Yusuke Sato 2015/02/04 02:00:28 Done.
+ nacl::NaClOpenExecutableResult /* open_result */)
// A renderer sends this to the browser process to determine how many
// processors are online.

Powered by Google App Engine
This is Rietveld 408576698